@@ -153,14 +153,32 @@ def find_arithmetic_prime_progressions(n):
     return arithmetic_prime_list
 
 def find_mersenne_primes(n):
+    '''
+    Return a list that has all mersenne primes below n.
+    '''
     _check_num(n)
     primes = set(all_primes(n))
     result = []
     for i in range(2, int(log(n + 1, 2)) + 1):
-        result.append(2**i - 1)
+        result.append(2 ** i - 1)
 
     mersenne_primes = primes.intersection(result)
-    return sorted(list(mersenne_primes))
+    return sorted(mersenne_primes)
+
+def find_fermat_pseudoprime(n):
+    '''
+    Return a list that has all fermat pseudoprimes below n.
+    '''
+    _check_num(n)
+    primes = all_primes(n)
+    a = 2
+    fermat_pseudoprimes = []
+    composites = [x for x in range(3, n + 1, a) if x not in primes]
+    for x in composites:
+        if (a ** (x - 1) - 1) % x == 0:
+            fermat_pseudoprimes.append(x)
+
+    return fermat_pseudoprimes
 
 def main():
     '''A test of this module.'''
@@ -170,7 +188,8 @@ def main():
     print(f'Reverse primes: {find_reverse(3000)}\n')
     print(f'Square palindome primes: {find_square_palindromes(500)}\n')
     print(f'Arithmetic prime progressions: {find_arithmetic_prime_progressions(125)}\n')
-    print(f'Mersenne Primes: {find_mersenne_primes(525000)}')
+    print(f'Mersenne Primes: {find_mersenne_primes(525000)}\n')
+    print(f'Fermat Pseudoprime: {find_fermat_pseudoprime(1000)}')
     end_tm = time()
     print(f'Time: {round(end_tm - start_tm, 12)} seconds.')
 
